@@ -183,9 +183,11 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
     warning("Value for argument 'tau.common' set to FALSE as argument 'byvar' is missing.")
     tau.common <- FALSE
   }
-  if (!missing.byvar & tau.common & !is.null(tau.preset)){
-    warning("Value for argument 'tau.preset' ignored as argument tau.common=TRUE.")
-    tau.preset <- NULL
+  if (!(method %in% c("MH", "Cochran"))){
+    if (!missing.byvar & !tau.common & !is.null(tau.preset)){
+      warning("Argument 'tau.common' set to TRUE as argument tau.preset is not NULL.")
+      tau.common <- TRUE
+    }
   }
   
   
