@@ -1,131 +1,92 @@
 metainf <- function(x, pooled, sortvar){
   
-  if (!inherits(x, "meta"))
-    stop("Argument 'x' must be an object of class \"meta\"")
   
-  
-  ## Upgrade meta objects created with older versions of meta
   ##
-  if (!(!is.null(x$version) &&
-        as.numeric(unlist(strsplit(x$version, "-"))[1]) >= 3.8))
-    x <- update(x, warn=FALSE)
-  
-  
-  level.comb <- x$level.comb
-  
-  
-  if (missing(pooled)){
-    if (length(x$comb.fixed)==0 & length(x$comb.random)==0)
-      pooled <- "fixed"
-    if (length(x$comb.fixed)>0 & length(x$comb.random)==0)
-      if (x$comb.fixed) pooled <- "fixed"
-      else pooled <- "NoNe"
-    if (length(x$comb.fixed)==0 & length(x$comb.random)>0)
-      if (x$comb.random) pooled <- "random"
-      else pooled <- "NoNe"
-    if (length(x$comb.fixed)>0 & length(x$comb.random)>0){
-      if (x$comb.fixed)
-        pooled <- "fixed"
-      if (!x$comb.fixed & x$comb.random)
-        pooled <- "random"
-      if (!x$comb.fixed & !x$comb.random)
-        pooled <- "NoNe"
-    }
-  }
   ##
-  if (pooled=="NoNe")
-    stop("Parameters \"comb.fixed\" and \"comb.random\" in object '",
-        deparse(substitute(x)),
-         "' are either 'FALSE' or 'NULL'. ",
-         "Please use argument \"pooled=fixed\" or \"pooled=random\" ",
-         "to select meta-analytical model.")
-  
-  
-  imeth <- charmatch(tolower(pooled), c("fixed", "random"), nomatch = NA)
+  ## (1) Check for meta object and upgrade older meta objects
   ##
-  if (is.na(imeth)) 
-        stop("'pooled' should be \"fixed\" or \"random\"")
   ##
-  pooled <- c("fixed", "random")[imeth]
-  
-  
-  if (length(level.comb)==0){
-    warning("level.comb set to 0.95")
-    level.comb <- 0.95
-  }
-  
-  
+  chkclass(x, "meta")
+  x <- updateversion(x)
+  ##
   k.all <- length(x$TE)
-  ##
-  if (k.all==1){
+  if (k.all < 2){
     warning("Nothing calculated (minimum number of studies: 2).")
     return(invisible(NULL))
   }
   
-  sort <- !missing(sortvar)
   
-  if (!sort) sortvar <- rep(1, k.all)
-  if (sort & length(sortvar) != k.all)
-    stop("'x' and 'sortvar' have different length")
-
-  
-  n.e <- x$n.e
-  n.c <- x$n.c
-  n   <- x$n
   ##
-  event.e <- x$event.e
-  event.c <- x$event.c
-  event   <- x$event
   ##
-  mean.e <- x$mean.e
-  mean.c <- x$mean.c
+  ## (2) Check other arguments
   ##
-  sd.e <- x$sd.e
-  sd.c <- x$sd.c
   ##
-  time.e <- x$time.e
-  time.c <- x$time.c
+  if (!missing(pooled))
+    pooled <- setchar(pooled, c("fixed", "random"))
+  else
+    if (!x$comb.fixed & x$comb.random)
+      pooled <- "random"
+    else
+      pooled <- "fixed"
   ##
-  cor <- x$cor
-  ##
-  TE <- x$TE
-  seTE <- x$seTE
-  ##
-  studlab <- x$studlab
-  sortvar <- sortvar
-  
-  
-  if (sort){
-    ##
-    o <- order(sortvar)
-    ##
-    n.e <- n.e[o]
-    n.c <- n.c[o]
-    n   <- n[o]
-    ##
-    event.e <- event.e[o]
-    event.c <- event.c[o]
-    event   <- event[o]
-    ##
-    mean.e <- mean.e[o]
-    mean.c <- mean.c[o]
-    ##
-    sd.e <- sd.e[o]
-    sd.c <- sd.c[o]
-    ##
-    time.e <- time.e[o]
-    time.c <- time.c[o]
-    ##
-    cor <- cor[o]
-    ##
-    TE <- TE[o]
-    seTE <- seTE[o]
-    ##
-    studlab <- studlab[o]
-    sortvar <- sortvar[o]
+  mf <- match.call()
+  error <- try(sortvar <- eval(mf[[match("sortvar", names(mf))]],
+                               as.data.frame(x, stringsAsFactors=FALSE),
+                               enclos = sys.frame(sys.parent())),
+               silent=TRUE)
+  if (class(error)=="try-error"){
+    xd <- x$data
+    sortvar <- eval(mf[[match("sortvar", names(mf))]],
+                    xd, enclos = NULL)
+    if (!is.null(x$data$.subset))
+      sortvar <- sortvar[x$data$.subset]
   }
+  sort <- !is.null(sortvar)
+  if (sort && (length(sortvar) != k.all))
+    stop("Number of studies in object 'x' and argument 'sortvar' have different length.")
+  if (!sort)
+    sortvar <- 1:k.all
   
   
+  ##
+  ##
+  ## (3) Sort variables
+  ##
+  ##
+  o <- order(sortvar)
+  ##
+  n.e <- x$n.e[o]
+  n.c <- x$n.c[o]
+  n   <- x$n[o]
+  ##
+  event.e <- x$event.e[o]
+  event.c <- x$event.c[o]
+  event   <- x$event[o]
+  ##
+  mean.e <- x$mean.e[o]
+  mean.c <- x$mean.c[o]
+  ##
+  sd.e <- x$sd.e[o]
+  sd.c <- x$sd.c[o]
+  ##
+  time.e <- x$time.e[o]
+  time.c <- x$time.c[o]
+  ##
+  cor <- x$cor[o]
+  ##
+  TE <- x$TE[o]
+  seTE <- x$seTE[o]
+  ##
+  studlab <- x$studlab[o]
+  slab <- c(paste("Omitting", studlab), "Pooled estimate")
+  studlab <- c(rev(rev(slab)[-1]), " ", rev(slab)[1])
+  
+  
+  ##
+  ##
+  ## (4) Do sensitivity analysis
+  ##
+  ##
   res.i <- matrix(NA, ncol=10, nrow=k.all)
   ##
   for (i in 1:k.all){
@@ -133,73 +94,96 @@ metainf <- function(x, pooled, sortvar){
     ##
     if (inherits(x, "metabin"))
       m <- metabin(event.e[sel], n.e[sel], event.c[sel], n.c[sel],
+                   ##
                    method=x$method, sm=x$sm,
                    incr=x$incr, allincr=x$allincr, addincr=x$addincr,
                    allstudies=x$allstudies, MH.exact=x$MH.exact,
                    RR.cochrane=x$RR.cochrane,
-                   level=level.comb, level.comb=level.comb,
+                   ##
+                   level.comb=x$level.comb,
+                   ##
                    hakn=x$hakn,
                    method.tau=x$method.tau,
                    tau.preset=x$tau.preset, TE.tau=x$TE.tau,
+                   ##
+                   keepdata=FALSE,
                    warn=FALSE)
     ##
     if (inherits(x, "metacont"))
       m <- metacont(n.e[sel], mean.e[sel], sd.e[sel],
                     n.c[sel], mean.c[sel], sd.c[sel],
+                    ##
                     sm=x$sm, pooledvar=x$pooledvar,
-                    level=level.comb, level.comb=level.comb,
-                    hakn=x$hakn,
-                    method.tau=x$method.tau,
-                    tau.preset=x$tau.preset, TE.tau=x$TE.tau)
-    ##
-    if (inherits(x, "metagen"))
-      if (!is.null(x$tau.preset))
-        m <- metagen(TE[sel], seTE[sel], sm=x$sm,
-                     level=level.comb, level.comb=level.comb,
-                     hakn=x$hakn,
-                     method.tau=x$method.tau,
-                     tau.preset=x$tau.preset, TE.tau=x$TE.tau)
-      else
-        m <- metagen(TE[sel], seTE[sel], sm=x$sm,
-                     level=level.comb, level.comb=level.comb,
-                     hakn=x$hakn,
-                     method.tau=x$method.tau,
-                     TE.tau=x$TE.tau)
-    ##
-    if (inherits(x, "metaprop"))
-      m <- metaprop(event[sel], n[sel],
-                    studlab=studlab[sel],
-                    sm=x$sm,
-                    incr=x$incr, allincr=x$allincr, addincr=x$addincr,
-                    method.ci=x$method.ci,
-                    level=level.comb, level.comb=level.comb,
+                    ##
+                    level.comb=x$level.comb,
+                    ##
                     hakn=x$hakn,
                     method.tau=x$method.tau,
                     tau.preset=x$tau.preset, TE.tau=x$TE.tau,
+                    ##
+                    keepdata=FALSE,
                     warn=FALSE)
     ##
     if (inherits(x, "metacor"))
       m <- metacor(cor[sel], n[sel],
-                   studlab=studlab[sel],
+                   ##
                    sm=x$sm,
-                   level=level.comb, level.comb=level.comb,
+                   ##
+                   level.comb=x$level.comb,
+                   ##
                    hakn=x$hakn,
                    method.tau=x$method.tau,
-                   tau.preset=x$tau.preset, TE.tau=x$TE.tau)
+                   tau.preset=x$tau.preset, TE.tau=x$TE.tau,
+                   ##
+                   keepdata=FALSE)
+    ##
+    if (inherits(x, "metagen"))
+      m <- metagen(TE[sel], seTE[sel],
+                   ##
+                   sm=x$sm,
+                   ##
+                   level.comb=x$level.comb,
+                   ##
+                   hakn=x$hakn,
+                   method.tau=x$method.tau,
+                   tau.preset=x$tau.preset, TE.tau=x$TE.tau,
+                   ##
+                   keepdata=FALSE,
+                   warn=FALSE)
     ##
     if (inherits(x,"metainc"))
       m <- metainc(event.e[sel], time.e[sel],
                    event.c[sel], time.c[sel],
-                   studlab=studlab[sel],
+                   ##
                    method=x$method,
                    sm=x$sm,
                    incr=x$incr, allincr=x$allincr, addincr=x$addincr,
-                   level=x$level, level.comb=x$level.comb,
+                   ##
+                   level.comb=x$level.comb,
+                   ##
                    hakn=x$hakn, method.tau=x$method.tau,
-                   tau.preset=x$tau.preset, TE.tau=x$TE.tau)
+                   tau.preset=x$tau.preset, TE.tau=x$TE.tau,
+                   ##
+                   keepdata=FALSE,
+                   warn=FALSE)
     ##
-    sel.pas <- inherits(x, "metaprop") & m$sm=="PAS"
-    sel.pft <- inherits(x, "metaprop") & m$sm=="PFT"
+    if (inherits(x, "metaprop"))
+      m <- metaprop(event[sel], n[sel],
+                    ##
+                    sm=x$sm,
+                    incr=x$incr, allincr=x$allincr, addincr=x$addincr,
+                    method.ci=x$method.ci,
+                    ##
+                    level.comb=x$level.comb,
+                    ##
+                    hakn=x$hakn,
+                    method.tau=x$method.tau,
+                    tau.preset=x$tau.preset, TE.tau=x$TE.tau,
+                    ##
+                    keepdata=FALSE,
+                    warn=FALSE)
+    ##
+    sel.pft <- inherits(x, "metaprop") & x$sm=="PFT"
     ##
     if (pooled == "fixed"){
       res.i[i,] <- c(m$TE.fixed, m$seTE.fixed,
@@ -231,8 +215,7 @@ metainf <- function(x, pooled, sortvar){
   n.harmonic.mean.i <- res.i[,9]
   if (pooled == "random" & x$hakn)
     df.hakn.i <- res.i[,10]
-  
-  
+  ##  
   if (pooled == "fixed"){
     TE.s <- x$TE.fixed
     seTE.s <- x$seTE.fixed
@@ -252,14 +235,16 @@ metainf <- function(x, pooled, sortvar){
   }
   
   
-  slab <- c(paste("Omitting", studlab), "Pooled estimate")
-  
-  
+  ##
+  ##
+  ## (5) Generate R object
+  ##
+  ##
   res <- list(TE=c(TE.i, NA, TE.s),
               seTE=c(seTE.i, NA, seTE.s),
               lower=c(lower.i, NA, TE.s.lower),
               upper=c(upper.i, NA, TE.s.upper),
-              studlab=c(rev(rev(slab)[-1]), " ", rev(slab)[1]),
+              studlab=studlab,
               p.value=c(pval.i, NA, pval.s),
               w=c(weight.i, NA, w.s),
               I2=c(I2.i, NA, x$I2),
@@ -272,16 +257,20 @@ metainf <- function(x, pooled, sortvar){
               TE.fixed=NA, seTE.fixed=NA,
               TE.random=NA, seTE.random=NA,
               Q=NA,
-              level.comb=level.comb,
+              level.comb=x$level.comb,
               hakn=x$hakn,
               method.tau=x$method.tau,
               tau.preset=x$tau.preset,
               TE.tau=x$TE.tau,
               n.harmonic.mean=c(n.harmonic.mean.i, NA, 1/mean(1/n)),
+              prediction=FALSE,
+              ##
+              backtransf=x$backtransf,
+              title=x$title, complab=x$complab,
+              outclab=x$outclab,
+              ##
               call=match.call())
   
-  res$backtransf <- x$backtransf
-  
   res$version <- packageDescription("meta")$Version
   
   class(res) <- c("metainf", "meta")
